@@ -1,10 +1,10 @@
 import matplotlib.pyplot as plt # plotting
 import os # for file/folder creations
 import keras
-from keras.models import Sequential
-from keras.layers import Dense, Dropout, Activation, Flatten, BatchNormalization, Input, Dense
-from keras.layers import Conv2D, MaxPooling2D
-from keras.models import Model
+from keras.models import Model, Sequential
+from keras.layers import Dense, Conv2D, MaxPooling2D, Dropout, Activation, Flatten, BatchNormalization, Input, Dense
+from keras.callbacks import ModelCheckpoint
+from keras.preprocessing.image import ImageDataGenerator
 
 # =======================================================================================
 # BEG: build custom model based on args
@@ -50,17 +50,39 @@ class TestModel:
     # ----------------------------------------------------------
     # Training and evaluation
     # ----------------------------------------------------------
-    def fit(self, train_data, val_data, v, args):
+    def fit(self, train_data, val_data, v, savename, args):
         """train_data, val_data are tuples of X and y"""
         if v==0:
             print("Wait for the big picture ☕️\n\nTrainng started ...")
         num_samples = train_data[0].shape[0] #X
         num_batches = num_samples / args.batch_size
-        
+
         callbacks_list = []
+        # custom callbacks (single only)
         if 'CustomCallback' in args.__dict__:
             callbacks_list.append(args.CustomCallback(num_batches))
         
+        # checkpointer callback
+        os.makedirs(f'BestSavedModels', exist_ok=True)
+        check = ModelCheckpoint(
+            filepath=f"./BestSavedModels/{savename}.h5",
+            verbose=v, save_best_only=True
+        )
+        callbacks_list.append(check)
+        
+        # data generator
+        traingen = ImageDataGenerator(**args.train_data_gen)
+        testgen  = ImageDataGenerator(**args.test_data_gen)
+
+        self.history = self.model.fit(
+            traingen.flow(train_data[0], train_data[1], args.batch_size),
+            validation_data = testgen.flow(val_data[0], val_data[1], batch_size=args.batch_size),
+            steps_per_epoch = len(train_data[0]) / args.batch_size, 
+            epochs          = args.epochs,
+            shuffle         = args.shuffle,
+            callbacks       = callbacks_list
+        )
+        """
         self.history = self.model.fit(
             train_data[0], #X
             train_data[1], #y
@@ -70,8 +92,8 @@ class TestModel:
             shuffle         = args.shuffle,
             verbose         = v,
             callbacks       = callbacks_list
-            
         )
+        """
     
     # evaluation
     def evaluate(self, x_test, y_test, v=1):
@@ -303,7 +325,6 @@ class TestModel:
     # for fcs_Seq
     def __get_dense(self, out_nodes, act, kernel_regularizer):
         """out_nodes is int and act is string """
-        print(kernel_regularizer)
         return Dense(out_nodes, activation=act, kernel_regularizer=kernel_regularizer)
     
     def __get_dropout(self, p):
